/**
 *
 */
package org.gcube.datacatalogue.metadatadiscovery.bean.jaxb;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;



/**
 * The Class MetadataFormat.
 *
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * Jun 8, 2016
 */
@XmlRootElement(name="metadataformat")
@XmlAccessorType(XmlAccessType.FIELD)
public class MetadataFormat implements Serializable{

	/**
	 *
	 */
	private static final long serialVersionUID = -5881074882343424963L;

	/**
	 * Instantiates a new metadata format.
	 */
	public MetadataFormat() {
	}

	@XmlElement(name = "metadatacategory")
	private List<MetadataCategory> metadataCategories;


	@XmlElement(name = "metadatafield")
	private List<MetadataField> metadataFields;

	@XmlTransient
	private String metadataSource = null;


	/**
	 * Gets the metadata fields.
	 *
	 * @return the metadataFields
	 */
	public List<MetadataField> getMetadataFields() {

		return metadataFields;
	}



	/**
	 * Gets the metadata categories.
	 *
	 * @return the metadataCategories
	 */
	public List<MetadataCategory> getMetadataCategories() {

		return metadataCategories;
	}



	/**
	 * Sets the metadata categories.
	 *
	 * @param metadataCategories the metadataCategories to set
	 */
	public void setMetadataCategories(List<MetadataCategory> metadataCategories) {

		this.metadataCategories = metadataCategories;
	}



	/**
	 * Sets the metadata fields.
	 *
	 * @param metadataFields the metadataFields to set
	 */
	public void setMetadataFields(List<MetadataField> metadataFields) {

		this.metadataFields = metadataFields;
	}

	/**
	 * Adds the metadata.
	 *
	 * @param Field the field
	 */
	public void addMetadata(MetadataField Field){
		if(this.metadataFields==null)
			this.metadataFields = new ArrayList<MetadataField>();

		this.metadataFields.add(Field);
	}


	/**
	 * Gets the metadata source.
	 *
	 * @return the metadata source
	 */
	public String getMetadataSource() {

		return metadataSource;
	}



	/**
	 * Sets the metadata source.
	 *
	 * @param metadataSource the new metadata source
	 */
	public void setMetadataSource(String metadataSource) {

		this.metadataSource = metadataSource;
	}



	/**
	 * Adds the category.
	 *
	 * @param metadataCategory the metadata category
	 */
	public void addCategory(MetadataCategory metadataCategory){
		if(this.metadataCategories==null)
			this.metadataCategories = new ArrayList<MetadataCategory>();

		this.metadataCategories.add(metadataCategory);
	}



	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {

		StringBuilder builder = new StringBuilder();
		builder.append("MetadataFormat [metadataCategories=");
		builder.append(metadataCategories);
		builder.append(", metadataFields=");
		builder.append(metadataFields);
		builder.append(", metadataSource=");
		builder.append(metadataSource);
		builder.append("]");
		return builder.toString();
	}


}
